@@ -1,8 +1,8 @@
-### cherry.R  (2002-08-28)
+### cherry.R  (2004-08-31)
 ###
 ###     Number of Cherries and Null Models of Trees
 ###
-### Copyright 2002 Emmanuel Paradis <paradis@isem.univ-montp2.fr>
+### Copyright 2004 Emmanuel Paradis <paradis@isem.univ-montp2.fr>
 ###
 ### This file is part of the `ape' library for R and related languages.
 ### It is made available under the terms of the GNU General Public
@@ -29,7 +29,7 @@ cherry <- function(phy)
     if (nb.node != n - 1) stop("\"phy\" is not fully dichotomous")
     if (n < 4) stop("not enough tips in your phylogeny for this analysis")	
     cherry <- sum(table(phy$edge[, 1][phy$edge[, 2] > 0]) == 2)
-    if (n < 20) small.n <- TRUE else small.n <- FALSE
+    small.n <- if (n < 20) TRUE else FALSE
     if (small.n) {
         P.yule <- f.cherry.yule(n, cherry)
         P.uniform <- f.cherry.uniform(n, cherry)
@@ -53,33 +53,16 @@ cherry <- function(phy)
 
 f.cherry.yule <- function(n, k)
 {
-    if (k == 0 | k > floor(n/2)) P <- 0
-    else {
-        if (n == 4) {
-            if (k == 1) P <- 2/3 else if (k == 2) P <- 1/3 else P <- 0
-        }
-        else {
-            P <- (1 - 2 * (k - 1)/(n - 1)) * f.cherry.yule(n - 1, k - 1) +
+    P <- if (k == 0 | k > floor(n/2)) 0 else if (n == 4) if (k == 1) 2/3 else if (k == 2) 1/3 else 0
+             else (1 - 2 * (k - 1)/(n - 1)) * f.cherry.yule(n - 1, k - 1) +
               2 * k/(n - 1) * f.cherry.yule(n - 1, k)
-        }
-    }
     P
 }
 
 f.cherry.uniform <- function(n, k)
 {
-    if (k == 0 | k > floor(n/2)) P <- 0
-    else {
-        if (n == 4) {
-            if (k == 1) P <- 4/5 else if (k == 2) P <- 1/5 else P <- 0
-        }
-        else {
-            if (k == 1) P <- 0
-            else
-              P <- (gamma(n + 1) * gamma(n - 2 + 1) * gamma(n - 4 + 1) * 2^(n-2*k)) /
-                (gamma(n -2 * k + 1) * gamma(2 * n - 4 + 1) * gamma(k + 1)
-                 * gamma(k - 2 + 1))
-        }
-    }
+    P <- if (k == 0 | k > floor(n/2)) 0 else if (n == 4) if (k == 1) 4/5 else if (k == 2) 1/5 else 0
+        else if (k == 1) 0 else (gamma(n + 1) * gamma(n - 2 + 1) * gamma(n - 4 + 1) * 2^(n-2*k)) /
+                (gamma(n -2 * k + 1) * gamma(2 * n - 4 + 1) * gamma(k + 1) * gamma(k - 2 + 1))
     P
 }
