@@ -44,14 +44,14 @@ diversi.gof <- function(x, null = "exponential", z = NULL)
     else cat(deparse(substitute(z)), "(user-specified)\n\n")
     cat("Cramr-von Mises test: W2 =", round(W2, 3))
     if (null == "exponential") {
-        if (W2 < 0.177) cat("   P > 0.1")
+        if (W2 < 0.177) cat("   P > 0.1\n")
         if (W2 >= 0.177 & W2 < 0.224) cat("   0.05 < P < 0.1\n")
         if (W2 >= 0.224 & W2 < 0.273) cat("   0.025 < P < 0.05\n")
         if (W2 >= 0.273 & W2 < 0.337) cat("   0.01 < P < 0.025\n")
         if (W2 > 0.337) cat("   P < 0.01\n")
     }
     else {
-        if (W2 < 0.347) cat("   P > 0.1")
+        if (W2 < 0.347) cat("   P > 0.1\n")
         if (W2 >= 0.347 & W2 < 0.461) cat("   0.05 < P < 0.1\n")
         if (W2 >= 0.461 & W2 < 0.581) cat("   0.025 < P < 0.05\n")
         if (W2 >= 0.581 & W2 < 0.743) cat("   0.01 < P < 0.025\n")
@@ -59,14 +59,14 @@ diversi.gof <- function(x, null = "exponential", z = NULL)
     }
     cat("Anderson-Darling test: A2 =", round(A2, 3))
     if (null == "exponential") {
-        if (A2 < 1.078) cat("   P > 0.1")
+        if (A2 < 1.078) cat("   P > 0.1\n")
         if (A2 >= 1.078 & A2 < 1.341) cat("   0.05 < P < 0.1\n")
         if (A2 >= 1.341 & A2 < 1.606) cat("   0.025 < P < 0.05\n")
         if (A2 >= 1.606 & A2 < 1.957) cat("   0.01 < P < 0.025\n")
         if (A2 > 1.957) cat("   P < 0.01\n")
     }
     else {
-        if (A2 < 1.933) cat("   P > 0.1")
+        if (A2 < 1.933) cat("   P > 0.1\n")
         if (A2 >= 1.933 & A2 < 2.492) cat("   0.05 < P < 0.1\n")
         if (A2 >= 2.492 & A2 < 3.070) cat("   0.025 < P < 0.05\n")
         if (A2 >= 3.070 & A2 < 3.857) cat("   0.01 < P < 0.025\n")
