@@ -8,13 +8,13 @@
 ### It is made available under the terms of the GNU General Public
 ### License, version 2, or at your option, any later version,
 ### incorporated herein by reference.
-### 
+###
 ### This program is distributed in the hope that it will be
 ### useful, but WITHOUT ANY WARRANTY; without even the implied
 ### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 ### PURPOSE.  See the GNU General Public License for more
 ### details.
-### 
+###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
 ### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
@@ -30,7 +30,7 @@ read.dna <- function(file, format = "interleaved", skip = 0,
     old.warn <- options("warn")
     options(warn = -1)
     ## need to remove the possible leading spaces in the first line
-    fl.num <- as.numeric(unlist(strsplit(gsub("^ ", "", fl), " +")))
+    fl.num <- as.numeric(unlist(strsplit(gsub("^ +", "", fl), " +")))
     options(warn = unlist(old.warn))
     if (format == "interleaved") {
         if (all(is.na(fl.num))) stop("the first line of the file must contain the dimensions of the data\n  if the format is interleaved.")
@@ -44,7 +44,7 @@ read.dna <- function(file, format = "interleaved", skip = 0,
         X <- X[-1]
         fl <- X[1]
         fl <- unlist(strsplit(fl, NULL))
-        bases <- grep("[AaCcGgTtUuMmRrWwSsYyKkVvHhDdBbNn]", fl)
+        bases <- grep("[-AaCcGgTtUuMmRrWwSsYyKkVvHhDdBbNn]", fl)
         z <- diff(bases)
         for (i in 1:length(z)) if (all(z[i:(i + 8)] == 1)) break
         start.seq <- bases[i]
